@@ -14,7 +14,10 @@ import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "test", "0.0.1", __name__[0:-6], "test@0.0.1.jsii.tgz"
+    "lllfahaider-test-cdk-construct-01",
+    "0.0.2",
+    __name__[0:-6],
+    "lllfahaider-test-cdk-construct-01@0.0.2.jsii.tgz",
 )
 
 __all__ = [
